@@ -1,4 +1,4 @@
-/* $Header: /local/src/CVS/nickle/type.c,v 1.65 2005-10-20 18:24:22 keithp Exp $ */
+/* $Header: /local/src/CVS/nickle/type.c,v 1.66 2005/12/10 22:11:45 bart Exp $ */
 
 /*
  * Copyright © 1988-2004 Keith Packard and Bart Massey.
@@ -811,6 +811,21 @@ TypeUnaryBool (Type *type)
     return 0;
 }
 
+/*
+ * Return the least-upper bound for a boolean computation
+ */
+static Type *
+TypeBinaryBool (Type *left, Type *right)
+{
+    if (TypePoly (left))
+	left = typePrim[rep_bool];
+    if (TypePoly (right))
+	right = typePrim[rep_bool];
+    if (TypeBool (left) && TypeBool (right))
+	return left;
+    return 0;
+}
+
 static void
 TypeEltMark (void *object)
 {
@@ -984,6 +999,11 @@ TypeCombineBinary (Type *left, int tag, Type *right)
 	if ((type = TypeBinaryIntegral (left, right)))
 	    ret = TypeAdd (ret, type);
 	break;
+    case ASSIGNAND:
+    case ASSIGNOR:
+	if ((type = TypeBinaryBool (left, right)))
+	    ret = TypeAdd (ret, type);
+	break;
     case COLON:
 	if (TypePoly (left) || TypePoly (right))
 	    ret = TypeAdd (ret, typePoly);
